#
# spec file for package telegram-desktop
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Disable LTO on TW due to build failures
%if 0%{?suse_version} > 01500
%define _lto_cflags %{nil}
%endif

%define __builder ninja

# gcc10 or higher is required
%if 0%{?suse_version} && ( 0%{?suse_version} < 1500 || ( 0%{?is_opensuse} && 0%{?suse_version} == 1500 && 0%{?sle_version} && 0%{?sle_version} <= 150400 ) )
%bcond_without  compiler_upgrade
%else
%bcond_with     compiler_upgrade
%endif

%define _dwz_low_mem_die_limit  40000000
%define _dwz_max_die_limit     200000000

%define qt_major_version 6

Name:           telegram-desktop
Version:        4.0.2
Release:        bp154.2.3.2
Summary:        Messaging application with a focus on speed and security
License:        GPL-3.0-only
Group:          Productivity/Networking/Instant Messenger
URL:            https://github.com/telegramdesktop/tdesktop
Source0:        https://github.com/telegramdesktop/tdesktop/releases/download/v%{version}/tdesktop-%{version}-full.tar.gz
# Use tg_owt-packager.py to prepare tg_owt-master.zip
# Usage: python tg_owt-packager.py --repo-dir $PWD/tg_owt-master
Source1:        tg_owt-packager.py
Source2:        tg_owt-master.zip
%if 0%{?suse_version} > 01500
# PATCH-FIX-OPENSUSE
Patch1:         0001-use-bundled-webrtc.patch
%else
Source3:        rnnoise-git20210122.tar.gz
# PATCH-FIX-OPENSUSE
Patch1:         0002-use-bundled-rnnoise-expected-gsl-ranges-webrtc.patch
%endif
# PATCH-FIX-OPENSUSE
Patch3:         0003-revert-webrtc-cmake-target-file.patch
# PATCH-FIX-OPENSUSE
Patch4:         0004-use-dynamic-x-libraries.patch
# There is an (incomplete) patch available for part of the source:
# https://github.com/desktop-app/lib_base.git 3582bca53a1e195a31760978dc41f67ce44fc7e4
# but tdesktop itself still falls short, and it looks to be something
# that would affect all ILP32 platforms.
ExcludeArch:    %ix86 aarch64_ilp32 ppc riscv32
BuildRequires:  appstream-glib
BuildRequires:  chrpath
BuildRequires:  clang
BuildRequires:  cmake >= 3.16
BuildRequires:  desktop-file-utils
BuildRequires:  enchant-devel
BuildRequires:  ffmpeg-devel
BuildRequires:  freetype-devel
%if %{with compiler_upgrade}
BuildRequires:  gcc10-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  glibc-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblz4-devel
BuildRequires:  libwebrtc_audio_processing-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  wayland-devel
BuildRequires:  webkit2gtk3-devel
BuildRequires:  xorg-x11-devel
BuildRequires:  xxhash-devel
BuildRequires:  xz
BuildRequires:  yasm
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  cmake(Qt%{qt_major_version}Concurrent)
BuildRequires:  cmake(Qt%{qt_major_version}Core)
BuildRequires:  cmake(Qt%{qt_major_version}DBus)
BuildRequires:  cmake(Qt%{qt_major_version}Network)
BuildRequires:  cmake(Qt%{qt_major_version}OpenGL)
BuildRequires:  cmake(Qt%{qt_major_version}Svg)
BuildRequires:  cmake(Qt%{qt_major_version}WaylandClient)
BuildRequires:  cmake(Qt%{qt_major_version}Widgets)
%if %{qt_major_version} >= 6
BuildRequires:  qt%{qt_major_version}-gui-private-devel
BuildRequires:  qt%{qt_major_version}-waylandclient-private-devel
BuildRequires:  cmake(Qt%{qt_major_version}Core5Compat)
BuildRequires:  cmake(Qt%{qt_major_version}OpenGLWidgets)
%else
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libqt5-qtwayland-private-headers-devel
BuildRequires:  pkgconfig(dbusmenu-qt%{qt_major_version})
%endif
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glibmm-2.4)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libmng)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libpcre16)
BuildRequires:  pkgconfig(libpcrecpp)
BuildRequires:  pkgconfig(libpcreposix)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libproxy-1.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-glx)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(mtdev)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(opusurl)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(portaudiocpp)
# Use system rnnoise on TW, self-build on others
%if 0%{?suse_version} > 01500
BuildRequires:  expect-devel
BuildRequires:  range-v3-devel
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(rnnoise)
%else
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
%endif
BuildRequires:  pkgconfig(tslib)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-record)
BuildRequires:  pkgconfig(xcb-renderutil)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(zlib)
# Runtime requirements
Requires:       hicolor-icon-theme
Requires:       icu
%if %{qt_major_version} >= 6
Requires:       qt%{qt_major_version}-imageformats
Recommends:     qt%{qt_major_version}-wayland
%else
Requires:       libqt%{qt_major_version}-qtimageformats
Recommends:     libqt%{qt_major_version}-qtwayland
%endif
# TDesktop can fall back to a simple GTK file picker but prefers the portal
Recommends:     xdg-desktop-portal
Recommends:     google-opensans-fonts

%description
Telegram is a non-profit cloud-based instant messaging service.
Users can send messages and exchange photos, videos, stickers, audio and files of any type.
Its client-side code is open-source software but the source code for recent versions is not
always immediately published, whereas its server-side code is closed-source and proprietary.
The service also provides APIs to independent developers.

%prep
%setup -q -n tdesktop-%{version}-full
%patch1 -p1
%patch3 -p1
%patch4 -p1
mkdir ../Libraries

# If not TW, unpack rnnoise source
%if 0%{?suse_version} <= 01500
%setup -q -T -D -b 3 -n tdesktop-%{version}-full
mv ../rnnoise-git20210122 ../Libraries/rnnoise
%endif

cd ../
unzip -q %{SOURCE2}
mv tg_owt-master Libraries/tg_owt

%build
%if %{with compiler_upgrade}
export CC=gcc-10
export CXX=g++-10
%endif

# Fix build failures due to not finding installed headers for xkbcommon and wayland-client
export CXXFLAGS+="`pkg-config --cflags xkbcommon wayland-client`"

# If not TW, build rnnoise
%if 0%{?suse_version} <= 01500
pushd %{_builddir}/Libraries/rnnoise
./autogen.sh
%configure
%make_build
popd
%endif

cd %{_builddir}/Libraries/tg_owt
mkdir -p out/Release
cd out/Release
cmake -G Ninja \
       -DCMAKE_BUILD_TYPE=Release \
       -DTG_OWT_SPECIAL_TARGET=linux \
       -DTG_OWT_LIBJPEG_INCLUDE_PATH=/usr/include \
       -DTG_OWT_OPENSSL_INCLUDE_PATH=/usr/include/openssl \
       -DTG_OWT_OPUS_INCLUDE_PATH=/usr/include/opus \
       -DTG_OWT_FFMPEG_INCLUDE_PATH=/usr/include/ffmpeg \
       -DTG_OWT_LIBVPX_INCLUDE_PATH=/usr/include/vpx \
       ../..
sed -i 's,gnu++2a,gnu++17,g' build.ninja
ninja

cd %{_builddir}/tdesktop-%{version}-full
# Use the official API key that telegram uses for their snap builds:
# https://github.com/telegramdesktop/tdesktop/blob/8fab9167beb2407c1153930ed03a4badd0c2b59f/snap/snapcraft.yaml#L87-L88
# Thanks to @primeos on Github.
%cmake \
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DCMAKE_BUILD_TYPE=Release \
%if %{qt_major_version} == 6
      -DDESKTOP_APP_QT6=ON \
%else
      -DDESKTOP_APP_QT6=OFF \
      -DDESKTOP_APP_DISABLE_WAYLAND_INTEGRATION=ON \
      -DDESKTOP_APP_USE_ENCHANT=ON \
%endif
      -DTDESKTOP_API_ID=611335 \
      -DTDESKTOP_API_HASH=d524b414d21f4d37f08684c1df41ac9c \
      -DDESKTOP_APP_USE_GLIBC_WRAPS=OFF \
      -DDESKTOP_APP_USE_PACKAGED=ON \
      -DDESKTOP_APP_QTWAYLANDCLIENT_PRIVATE_HEADERS=OFF \
      -DDESKTOP_APP_USE_PACKAGED_FONTS=ON \
      -DDESKTOP_APP_DISABLE_CRASH_REPORTS=ON \
      -DTDESKTOP_LAUNCHER_BASENAME=%{name} \
      -DDESKTOP_APP_SPECIAL_TARGET=""

%cmake_build

%install
%cmake_install

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.metainfo.xml

%files
%license LICENSE LEGAL
%doc README.md changelog.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/metainfo/*.metainfo.xml

%changelog
* Sun Jul 10 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix boo#1193516
* Sun Jun 26 2022 Xu Zhao <i@xuzhao.net>
- Add 0002-use-bundled-rnnoise-expected-gsl-ranges-webrtc.patch
  * Fix the build on openSUSE 15.4
- Rename 0001-use-bundled-ranged-exptected-gsl.patch to
  0001-use-bundled-webrtc.patch
  * Use system provided ranged, gsl, and ranges library.
* Sat Jun 25 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.0.2
  * Fix window title on Windows 7. (again)
  * Fix file chooser and global menu on macOS.
  * Crash fix and OpenAL check for PipeWire fix on Linux.
* Fri Jun 24 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.0.1
  * Fix window title on Windows 7.
  * Bug fixes and other minor improvements.
* Fri Jun 24 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update tg_owt; this does not include pipewire anymore, therefore:
  * Add BuildRequires: pkgconfig(libpipewire-0.3)
- Remove patches no longer needed:
  * 0002-tg_owt-fix-name-confliction.patch
  * 0005-add-wayland-include-path.patch
  * fix-unused-variable-error.patch
- Add suport for Qt version 6
- Update to version 4.0.0
  * Premium: Send media and files each up to 4 GB in size.
  * Premium: Download media and files at the fastest possible speed,
    with no limits.
  * Premium: Double most of the limits in the app.
  * Premium: Get a new button next to any voice message to generate
    a transcript of its audio.
  * Premium: React with even more emoji, including :clown: and 😍.
  * Premium: Send unique stickers with additional effects, updated
    monthly.
  * Premium: Set a default chat folder or enable tools to
    auto-archive and hide new chats.
  * Premium: Subscribers have a badge next to their name, showing
    they help support Telegram.
  * Premium: Show off your profile video that will be animated for
    everyone in chats and the chat list.
  * Premium: Sponsored Messages that are sometimes shown in public
    channels will no longer appear.
  * Enable join requests for your public groups – no invite links
    required.
  * Users who open the group will see an Apply to Join Group button.
  * Once approved by an admin, users will be able to participate in
    the chat.
  * Bots that are integrated into the attachment menu can be programmed
    to work in groups and channels.
- Update to version 3.7.6
  * Settings > Advanced > Experimental adds an option to open chats
    in separate windows.
  * Fix possible crash in video chat reconnection.
  * Fix possible crash after account switch.
- Update to version 3.7.5
  * Improve cloud password management design.
  * Fix a crash in shared media search.
  * Fix audio recording on macOS.
- Update to version 3.7.4
  * More icons for chat folders.
  * Improve some more sections design.
  * Update the OpenAL library to 1.22.0.
* Fri Jun  3 2022 marec <marec@detebe.org>
- fix for leap 15.4
* Tue May 10 2022 Илья Индиго <ilya@ilya.cf>
- Fixed requirements for Qt6 (boo#1199323).
* Tue Apr 26 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.7.3
  * Fix a crash in the pinned bar bot button refresh.
- Update to version 3.7.2
  * Fix mute period selector values.
  * Fix a crash in repeated context menu item selection.
  * Fix context menu item selection of systems without a compositor.
- Update to version 3.7.1
  * Hardware accelerated video decoding off by default.
  * Fix several crashes.
- Update to version 3.7.0
  * NO SUPPORT FOR QT5 ON LINUX ANYMORE! USE QT6!
  * Use any short music file or voice message as a notification sound.
  * Right click audio files in chats to add them to your list of
    sounds - or use 'Upload Sound' in the Notifications menu.
  * Click on Mute notifications > Select sound in a chat's (...)
    menu to change its notification sound.
  * Set custom tones for notifications in Settings > Notifications > Play sound.
  * Click on Mute notifications in a chat's (...) menu to manage
    its notifications.
  * Choose 'Mute for...' to turn off notifications for a
    preset period, like 1 hour or 1 day.
  * Quickly configure Auto-Delete settings from any chat info page.
  * Click (...) to turn on Auto-Delete, then select a specific duration.
  * Replies are now preserved when forwarding messages,
    making forwarded conversations easier to read.
  * Bots can now open detailed pages directly in the chat.
  * Use these streamlined interfaces to buy real-world goods
    and services without leaving the app.
  * Open a bot's profile to add it to your group or channel.
  * Instantly configure a bot's rights and permissions when adding it.
  * Bots can send a new type of button that lets you add them to
    your group or channel.
- Added fix-unused-variable-error.patch
* Fri Apr  8 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.6.1
  * Change volume for RTMP stream from the context menu.
  * Set a profile photo from your camera.
  * Improve RTMP stream full screen mode.
  * Improve edit account section design.
  * Fix switching personal account or channel in video chats.
  * Fix pinning chats in folders with 100 chats.
  * Fix YouTube timestamp links after 10 hours.
- Update tg_owt
* Sun Mar 13 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.6.0
  * Active and recently finished downloads pop up in bar in the
    bottom left corner, like they do in browsers.
  * View recently downloaded files in Settings > Advanced
    > Downloads.
  * Get an alert before closing the app if you have
    unfinished downloads.
  * Share a direct t.me link to your phone number that instantly
    opens a chat with you. Use the full number in
    international format, like t.me/+123456789
  * Manage Live Streams in your channels using external software
    like OBS Studio or XSplit Broadcaster. Choose "Stream With..."
    when staring a video chat or live stream - then copy your
    Stream Key and paste it into your streaming software.
- Update tg_owt
* Wed Feb  9 2022 Xu Zhao <i@xuzhao.net>
- Update to 3.5.2
  * Fix a freeze in audio playback on Linux.
  * Fix a crash in screen sharing initialization on Linux.
- Remove 0003-add-qt5-widgets-include.patch
  * Bug fixed in upstream
- Add 0003-revert-webrtc-cmake-target-file.patch
  * Fix target "desktop-app::external_opus" not found error.
* Fri Feb  4 2022 Xu Zhao <i@xuzhao.net>
- Add 0003-add-qt5-widgets-include.patch
  * Fix Qt5Widgets private header include issue.
* Thu Feb  3 2022 Xu Zhao <i@xuzhao.net>
- Update to 3.5.0
  * Use a new type of detailed stickers with smooth animations.
  * Create new sets by sending .webm videos to @stickers.
  * Bring your custom animated stickers from other apps.
  * See smaller, compact animations when reacting to messages.
  * See real-time animations in chat when a user reacts to your message.
  * React with additional emoji expressing love, appreciation,
    anger or surprise.
  * Tap the new button in chats to jump to your messages that have
    unseen reactions.
  * Watch the animations for unseen reactions play when you
    hit the button.
  * The app will warn you before closing if you are uploading
    photos or files to a chat.
  * Enjoy better screencast quality in video chats.
- Update tg_owt
- Rebase patches
* Tue Jan  4 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.4.3
  * Bug fixes and other minor improvements.
* Fri Dec 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.4.2
  * Bug fixes and other minor improvements.
* Fri Dec 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.4.1
  * Bug fixes and other minor improvements.
* Thu Dec 30 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.4.0
  * Send reactions to messages.
  * Group and Channel admins can enable reactions in their chat
    via '...' * menu > Manage > Reactions.
  * Select text when typing and choose 'Formatting > Spoiler'
    in the context menu to hide some or all of the contents of
    a message.
  * Click on the spoiler in chat to reveal its hidden text.
  * Spoiler formatting hides text in chat, as well as in
    the chat list and notifications.
- Update tg_owt
* Sun Dec 12 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Add tg_owt-packager.py to Source list in spec
* Sat Dec 11 2021 Xu Zhao <i@xuzhao.net>
- Update to 3.3.0
  * Content creators can restrict the ability to save media and
    forward messages from their groups and channels.
  * Clear messages in one-on-one chats from a specific day or
    date range.
  * Comment as one of your channels in public groups and channel
    comments.
- Add tg_owt-packager.py
* Tue Dec  7 2021 Xu Zhao <i@xuzhao.net>
- Update to 3.2.8
  * Fix crash in opening shared media with another user.
  * Try out the new audio player with playlist shuffle and repeat.
  * Give a custom name to your desktop session to distinguish it
    in the sessions list.
- Update tg_owt
* Fri Oct 29 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.1.11
  * Create special invite links that require admins to approve users
    before they become members.
  * Admins can view the applicants' profiles and bios by tapping the
    Join Requests bar at the top of the chat.
  * Add internal labels to your chat's Invite Links to keep them
    organized.
  * Run natively on Apple Silicon
- Update tg_owt
* Mon Oct 11 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.1.9
  * Show small media previews in chats list.
  * Show media album previews and caption text in chats list.
  * Add "Quick Reply" and "Mark as Read" to native
    Windows notifications.
* Thu Sep 30 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Add explicit BuildRequires for webkit2gtk-4.0
* Tue Sep 28 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 3.1.1
  * Choose one from dozens of new gorgeous animated backgrounds in
    Chat Settings > Chat background.
  * Tile chat background patterns horizontally.
  * Broadcast video and share your screen to an unlimited number of
    viewers.
  * To begin, tap the Live Stream button in the title bar of a
    community where you are an admin.
  * Tap the "Forward Message" label above the input field to change
    how messages will be sent.
  * Hide or show the original sender's name.
  * Remove or keep captions from media messages.
  * See how many unread comments there are when opening a
    channel's comments.
  * Check who've seen your message in small groups from the
    context menu.
  * Enable recording with video in live streams and video chats.
  * Add a "Close to Taskbar" option when tray icon is disabled.
  * Add support for Emoji 13.1.
  * Some animated emoji now have extra effects.
  * Send fireworks tada, balloon, :like:, hankey or heart to any
    private chat, then click on the animated emoji to launch the
    effect.
  * If your chat partner also has the chat open, you will both see
    the effects.
  * See the "Watching" status when your chat partner is enjoying
    emoji effects with you.
  * More interactive emoji coming soon.
  * Right click one of your outgoing messages in small groups to see
    who recently viewed it.
  * To protect privacy, read receipts are only stored for 7 days
    after the message was sent.
  * Record video and audio from live broadcasts in your group
    or channel.
  * Admins can start recording from the '...' menu.
  * Choose between recording in portrait or landscape orientation.
  * Finished recordings are sent to the admin's Saved Messages and
    can be easily shared.
- Update tg_owt
- Remove 0003-prioritize-gtk2.patch, the file it was applied to
  was removed upstream
- Enable GCC11 again
* Mon Aug 30 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable build on armv6/armv7 since the build has been fixed
  upstream
* Mon Aug  2 2021 Xu Zhao <i@xuzhao.net>
- Update to 2.9.0
  * Enable auto-delete in your chats to remove messages.
  * Quickly find all GIFs from a chat using the new GIF section.
  * Reset your Two-Step Verification password even if you forgot.
  * Enjoy a new app icon and default background.
- Update tg_owt
- Update 0001-use-bundled-ranged-exptected-gsl.patch
  * Use bundled rlottie
- Add 0004-use-dynamic-x-libraries.patch
- Add 0005-add-wayland-include-path.patch
* Sat Jun  5 2021 Xu Zhao <i@xuzhao.net>
- Add 0003-prioritize-gtk2.patch and enable GTK integration.
  Fixes boo#1149986 regression.
* Fri May 28 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Temporarily stick to GCC10 to work around build failures
* Sun May  9 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.7.5 (beta)
  * Add "Voice chats" filter in "Recent actions" for channels.
  * Write local drafts to disk on a background thread.
  * Support autoupdate for Telegram in write-protected folders
    on Linux.
  * Fix crash in native notifications on Linux.
  * Fix crash in file dialog on Linux.
- Update tg_owt
* Wed Apr 28 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.7.4
  * Fix crash in viewing an invoice after a payment is made.
  * Respect Focus Assist only for native notifications.
  * Mark messages as read only in active window.
* Tue Apr 27 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.7.3
  * Fix crash on some versions of Linux.
  * Fix video not stopping when PiP window is closed.
  * Fix messages marking as read if the Windows session is locked.
* Mon Apr 26 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.7.2
  * Offer real goods and services for sale in any group, channel or bot
    – Telegram doesn't charge a commission.
  * Pay for goods securely using one of the 8 integrated payment providers
    – Telegram doesn't collect your payment info.
  * See how this works in our @teststore.
  * Schedule voice chats to let participants know about them in advance.
  * View a countdown to the voice chat and get notified when it starts.
- Update tg_owt
- Drop telegram-desktop-cinttypes-header.patch, fixed upstream
* Tue Mar 23 2021 Jan Engelhardt <jengelh@inai.de>
- Expand the ExcludeArch.
* Mon Mar 22 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Exclude i586, support was dropped upstream
  (gh#telegramdesktop/tdesktop#10037)
* Mon Mar 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add telegram-desktop-cinttypes-header.patch: Include cinttypes
  header to use uint32_t.
- Add xkbcommon and wayland header dirs to CXXFLAGS to fix build
  failures.
- Require Qt >= 5.15: Required since version 2.5.9
  (gh#telegramdesktop/tdesktop#10398).
- Pass -q to unzip to avoid echoing long file list while
  unzipping.
* Mon Mar 22 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.7.1
  * Fix editing 'Manage Voice Chats' rights for channel admins.
  * Fix verification check display in voice chat participants list.
  * Allow removing and blocking channels from voice chats.
- Update tg_owt
* Sat Mar 20 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.7.0
  * Start limitless Voice Chats in Groups and Channels.
  * Host discussions that can be listened to by millions of people
    simultaneously.
  * Record voice chats to share or publish in Channels later.
  * See that a chat is being recorded from the red dot next to
    its title.
  * See user bio texts right from the list of participants.
  * Raise your hand to show admins you want to speak.
  * Create separate Voice Chat Invite Links for listeners or speakers.
  * Change the title of your Voice Chat to give people an idea
    of the current topic.
  * Join Voice Chats as one of your Channels to hide your
    personal account.
* Thu Mar 18 2021 Martin Liška <mliska@suse.cz>
- Use higher dwz memory limits for the package.
* Sat Mar 13 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.6.2
  * Fix text disappearing because of cloud drafts sync.
* Wed Feb 24 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.6.1
  * Fix time formatting in links.
  * Fix copy QR code in night mode.
  * Fix invite link sharing without a comment.
  * Fix crash in link editing on Linux.
* Tue Feb 23 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.6.0
  * Set messages to auto-delete for everyone 24 hours or 7 days
    after sending.
  * Control auto-delete settings in any of your chats, as well as
    in groups and channels where you are an admin.
  * To enable auto-delete, right click on the chat in the
    chat list > Clear History > Enable Auto-Delete.
  * Create invite links that work for a limited time or a limited
    number of uses.
  * See which users joined using your, or your admins', invite links.
  * Turn any invite link into a QR code users can scan with their
    phone cameras.
  * To manage invite links, click ... > Manage Group/Channel
    > Invite Links.
  * Convert groups that have reached 200,000 members into unlimited
    Broadcast Groups.
- Remove 0000-gtk2-default.patch, the code was removed upstream,
  meaning GTK integration is again broken, see boo#1149986
* Wed Feb 17 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.5.9
  * Add 'Invite via Link' button to Add Members box.
  * Fix window size in Windows 10 Tablet Mode.
  * Fix layout of round video messages in channels.
- Update tg_owt
* Sun Jan 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.5.8
  * Fix OpenAL device closing in calls and voice chats.
  * Fix video chat rotation when calling from iOS.
  * Fix scheduling messages without sound.
  * Remove redundant Cancel button in ScheduleBox.
* Thu Jan 28 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.5.7
  * Delete not only messages, but also groups you created and
    call history for all sides, without a trace.
  * Adjust volume for individual participants of a voice chat.
  * Report fake groups or channels impersonating famous people or
    organizations by opening their Profile > ... > Report.
* Mon Jan 25 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.5.6 (beta)
  * Press Up arrow to edit your last sent comment.
  * Add more information to date tooltips in Recent Actions and
    channel comments.
  * Bug andicrash fixes.
- Update tg_owt
- Rebase 0000-gtk2-default.patch
* Mon Jan 18 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.5.5 (beta)
  * Fix recording of audio in voice chats.
  * Fix media viewer zoom and crashing.
- Update tg_owt
- Add Recommends for google-opensans-fonts
* Fri Jan  8 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.5.4 (beta)
  * Implement new audio module code for calls and voice chats.
  * Allow retracting votes from polls in comments to channel posts.
  * Show small voice chat button for empty voice chats.
  * Fix media viewer updating when screen resolution is changed.
- Update tg_owt
  * adapt 0002-tg_owt-fix-name-confliction.patch
* Thu Jan  7 2021 Andrés Barrantes Silman <andresbs@opensuse.org>
- Adds a missing runtime dependency (libqt5-qtimageformats).
* Wed Dec 30 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.5.3 (beta)
  * Allow using mouse buttons in Push-to-Talk shortcut.
  * Fix blurred thumbnails in Shared Links section.
* Fri Dec 25 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.5.2 (beta)
  * Fix possible crash in video calls.
  * Fix possible crash in connecting to voice chats.
* Wed Dec 23 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.5.1
  * Turn any of your group chats into a hop-on, hop-off conference call.
  * Get up to several thousand participants in each voice chat.
  * Control the number of speakers with flexible admin tools.
  * Fix crash in voice calls.
* Sat Dec 19 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.15 (beta)
  * Improve design of voice chats.
  * Fix sending of voice messages as replies.
  * Fix 'Open With' menu position in macOS.
  * Fix freeze on secondary screen disconnect.
- Update tg_owt
* Tue Dec 15 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.14 (beta)
  * Create voice chats in legacy groups.
  * Fix sticker pack opening.
  * Fix group status display.
  * Fix group members display.
* Wed Dec  9 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.13 (beta)
  * Voice chats in groups.
  * Fix voice messages sending.
  * Fix crash in voice calls.
- Update tg_owt
* Sun Nov 22 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.11 (beta)
  * Upgrade Qt to version 5.15.1.
  * Upgrade FFmpeg to version 4.2.
  * Upgrade OpenAL to version 1.20.1.
  * Fix crash in tray icon removing.
  * Use inline bots and sticker by emoji suggestions in
    channel comments.
  * Lock voice message recording, listen to your voice message
    before sending.
  * Improve locked voice message recording.
  * Fix main window closing to tray on Windows.
  * Fix crash in bot command sending.
  * Fix adding additional photos when sending an album to a group
    with enabled slow mode.
- Update tg_owt
- Remove explicit Requires: for ffmpeg and openssl
* Thu Nov  5 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.7
  * Fix playback display in albums of music files.
  * Several crash fixes.
* Mon Nov  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.6
  * Fix image compression option when sending files with drag-n-drop.
  * Fix caption text selection in media albums.
  * Fix drafts display in personal chats in the chats list.
  * Bug fixes and other minor improvements.
- Update tg_owt
* Fri Oct 30 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.5
  * Pin several messages in any chat, including one-on-one chats.
  * Jump between pinned messages or open them all on a separate page
    via the top bar.
  * Send several music tracks as a playlist.
  * Send several files as an album in one chat bubble.
  * Send a :slot_machine: emoji to any chat to see if you
    hit the jackpot.
  * Hide Telegram taskbar icon on Linux in Settings > Advanced.
- Update tg_owt
* Mon Oct 26 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.4
  * Fix application quit on call end with main window hidden in tray.
  * Update OpenAL library on Windows.
  * Several crash fixes.
- Stricter constraints for i586
* Fri Oct 16 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Lower constraints on Arm
* Thu Oct 15 2020 Adrian Campos Garrido <adriancampos@teachelp.com>
- Delete the limitation and build for all platforms including aarch64
* Wed Oct  7 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.3
  * Fix sending voice messages in scheduled messages section.
  * Fix deleting profile / group / channel photos.
  * Several crash fixes.
* Fri Oct  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.2
  * Allow block, report and delete all message from user from
    "user joined" service message context menu.
  * Fix admin badge display in groups.
  * Fix loading and opening of comments in channels.
* Fri Oct  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.1
  * Move by PageUp and PageDown in channel comments.
  * Several layout bugfixes.
  * Several crashfixes.
* Thu Oct  1 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.0
  * Turn on "Remain Anonymous" in an admin's Permissions to
    let them post on behalf of the group and become invisible
    in the list of members.
  * Comment on posts in channels that have a discussion group.
  * Get notified about replies to your comments via the new
    Replies chat (if you are not a member of the discussion group).
- Remove check_if_xcb-screensaver_present.patch, obsolete
- Update tg_owt and patches
* Wed Sep 30 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Add check_if_xcb-screensaver_present.patch
  * fixes boo#1176626: Telegram-desktop crashes on Xwayland
* Sun Aug 30 2020 Xu Zhao <i@xuzhao.net>
- Update to 2.3.2
  * Revert custom window shadow on Linux.
- Update in 2.3.1
  * Fix Calls Settings for Video Calls.
- Update in 2.3.0
  * Video Calls (alpha version).
- Updates in 2.2.0, 2.1.22, and 2.1.21
  * Quickly switch between different Telegram accounts
    if you use multiple phone numbers.
  * Share and store unlimited files of any type up to 2 GB each.
  * Edit your scheduled messages.
  * Use Auto-Night Mode to make Telegram night mode match system
    Dark Mode settings
  * Also added an option to switch to system window frame
    in Windows and Linux.
  * Fix crash in web page preview display
- Rebase 0000-gtk2-default.patch
  * Prioritize qgtk2 platform plugin
- Rename 0001-use-bundled-range.patch to
  0001-use-bundled-ranged-exptected-gsl.patch
  * Use bundled ranged-v3, Microsoft GSL, and expected.
- Add 0002-tg_owt-fix-name-confliction.patch
  * Patch tg_owt library to fix header name conflict with openssl
  * Include <stdint> header to define int types like uint32_t
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Wed Jun 24 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.13
  * Fix photos loading.
  * Fix Picture-in-Picture window movement on Wayland in Linux.
* Thu Jun 18 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.12
  * Fix sticker and video results in inline bots.
  * Fix clipboard issues in Linux.
  * Fix several crashes.
* Mon Jun  8 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.11
  * Fix launching on old Linux systems.
* Fri Jun  5 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- update to 2.1.10
  * Improve memory usage.
  * Add support for full group message history export.
  * Allow export of a single chat message history in JSON format.
* Wed Jun  3 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.8 (beta)
  * Add support for full group message history export.
  * Allow export of a single chat message history in JSON format.
- Rebased 0000-gtk2-default.patch
* Sun May 24 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.7
  * Fix the Fcitx input method plugin.
* Wed May 13 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.5
  * Disable the taskbar icon flash or the dock icon bounce in
    Settings > Notifications.
  * View messages containing long monospace texts in wide bubbles.
  * Bug fixes and other minor improvements.
- rebased 0001-use-bundled-range.patch
* Sat May  9 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.4
  * Improve bold font selection.
* Fri May  8 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.3
  * Added support for new emoji.
  * Channels to which you can't post will no longer be suggested
    when forwarding.
  * Improved font selection and bold font support for CJK and Farsi.
  * Fix polls and quizes results viewing.
  * Fix memory leak in web page previews with autoplayed videos.
  * Fix running on OS X 10.10.
  * Other minor bug fixes and improvements.
- removed range-v3-master.zip, range is now bundled in the
  upstream source
- rebased 0001-use-bundled-range.patch
* Sat May  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.1
  * Improve quiz explanation tooltip layout.
  * Fix possible crash in theme editor.
  * Other minor bug fixes and improvements.
- Remove 0002-fix-directory-open-via-portals.patch
  * this release already contains the fix
* Sat Apr 25 2020 Markus S <kamikazow@opensuse.org>
- Update to 2.1.0
  * Access a catalog of over 20,000 stickers made by professional
    artists from the updated Sticker Panel by clicking the '+' icon.
  * Use sticker search to find the stickers you're looking for
    or scroll from the latest packs all the way to the classics.
  * Add explanations that appear after users respond to a quiz question.
  * See how much time you have left to answer a question from
    @QuizBot with the new countdown animation.
  * Send a single :dart: emoji to see if you hit the bullseye.
- Disable libdee requirement after Python2 removal
- Upstream recommends using xdg-desktop-portal, so we might do the same
- Add 0002-fix-directory-open-via-portals.patch
  * Upstream fix for a bug when opening directories via portals
* Tue Mar 31 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.0.1
  * Switch between folders using Ctrl+1, ..., Ctrl+8.
  * Fix crash when a pinned in folder chat was added to archive.
  * Fix font issues in Linux version.
* Mon Mar 30 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.0.0
  * Organize chats into Chat Folders if you have too many chats.
  * Create custom folders with flexible settings, or use default
    recommendations.
  * Pin an unlimited number of chats in each folder.
  * Switch between folders in the new side bar to easily access
    all of your chats.
  * Send :dice: to any chat to try your luck and get a random number
    from the animated dice.
  * Send :virus:, :face_with_thermometer:, :mask:,
    :face_with_head_bandage:, :sneeze:, :sick:, :soap: or :ambulance:
    to try out the new animated emoji.
* Tue Mar 17 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.21
  * Mark new messages as read while scrolling down through them.
  * Improved spellchecking on Windows 7 and Linux.
  * Fix crash in shared links search.
  * Fix blurred thumbnails in albums with video files.
  * Fix a possible crash in animated stickers rendering.
  * Bug fixes and other minor improvements.
* Tue Feb 18 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.14
  * Bug fixes and other minor improvements.
* Wed Feb 12 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.13
  * Bug fixes and other minor improvements.
* Tue Feb 11 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.12
  * Switch to the Picture-in-Picture mode to watch your video in a
    small window.
  * Change video playback speed in the playback controls '...' menu.
  * Rotate photos and videos in the media viewer using the rotate
    button in the bottom right corner.
* Wed Jan 29 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.9
  * Bug fixes and other minor improvements.
- Removed 0002-use-bundled-rlottie.patch,
  there's a cmake switch for this
- Add cmake version requirement
* Fri Jan 24 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.8
  * Bug fixes and other minor improvements.
* Thu Jan 23 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.7
  * Create three new kinds of polls.
  * See who voted for what in polls with visible votes.
  * Vote for several options in polls that allow multiple answers.
  * Guess the correct answer in quiz-style polls.
  * Explore various ways of combining the different poll options.
  * Add polls from the '...' menu in any group or channel.
  * Use bots like @quizbot to create quizzes with several questions
    and media attachments.
  * Schedule messages to be sent when your recipient comes online
    (only works if you know their online status).
- Clean up spec file
* Wed Jan 22 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.6
  * Bug fixes and other minor improvements.
- Removed 0005-Use-system-wide-fonts.patch and
  0006-Revert-Disable-DemiBold-fallback-for-Semibold.patch,
  option to use system fonts added upstream
* Fri Jan 17 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.4
  * Bug fixes and other minor improvements.
- Removed patches, option to use distribution libraries
  added upstream:
  * 0001-Dynamic-linking-system-libs.patch
  * 0002-Dynamic-linking-system-qt.patch
  * 0004-gtk3.patch
- Added patches for dependencies not available from repos:
  * 0001-use-bundled-range.patch
  * 0002-use-bundled-rlottie.patch
* Thu Jan 16 2020 Xu Zhao <i@xuzhao.net>
- Upgrade to 1.9.3
  * Videos in chats start playing automatically.
  * Resume playback from where you left off when watching long
    videos and listening to long audio tracks.
  * Control automatic playback for videos, GIFs and round video
    messages in Settings > Advanced > Automatic media download.
  * Enjoy system spell checker support on all modern systems.
- Switch build system to Ninja
- Rename default-gtk2.patch to 0000-gtk2-default.patch,
  removed tdesktop.patch
- Added patches:
  * 0001-Dynamic-linking-system-libs.patch
  * 0002-Dynamic-linking-system-qt.patch
  * 0004-gtk3.patch
  * 0005-Use-system-wide-fonts.patch
  * 0006-Revert-Disable-DemiBold-fallback-for-Semibold.patch
* Tue Nov  5 2019 Xu Zhao <i@xuzhao.net>
- Remove the TDESKTOP_DISABLE_GTK_INTEGRATION macro in patch.py
  * Enable the native notification on all platforms.
- Add default-gtk2.patch: Use GTK 2 theme by default to harmonize
  the libqt5-prioritise-gtk2-platformtheme.patch (boo#1149986)
  in libqt5-qtbase.
* Sat Nov  2 2019 Xu Zhao <i@xuzhao.net>
- Update to 1.8.15
  * Bug fixes and other minor improvements.
* Sat Sep 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.9
  * Bug fixes and other minor improvements.
* Tue Sep 10 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.8
  * Create new themes based on your color and wallpaper choices.
  * Share your themes with other users via links.
  * Update your theme for all its users when you change something.
* Tue Sep 10 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.7 (beta)
  * Bug fixes and other minor improvements.
- Disable GTK integration again due to Cinnamon hard requiring
  libqt5-qtstyleplugins-platformtheme-gtk2 (boo#1149130)
* Mon Sep  9 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.5 (beta)
  * Create new themes based on your color and wallpaper choices.
  * Share your themes with other users via links.
  * Update your theme for all its users when you change something.
* Fri Sep  6 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.4
  * Bug fixes and other minor improvements.
- Updated rlottie
* Fri Sep  6 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.3
  * Right click the 'Send' button and select 'Schedule Message'
    to automatically send something at a specified time.
  * Schedule reminders for yourself in the 'Saved Messages' chat.
  * Get a notification when any of your scheduled messages are sent.
  * Customize your app's appearance by choosing accent colors for
    the 'Day', 'Night' and 'Tinted' themes.
  * Choose who can find you on Telegram when they add your number
    to their phone contacts.
  * Send a single :grin:, :anguished:, :rage:, :poo:, :cry:
    or :open_mouth: to check out what's new in the animated
    emoji department.
* Wed Aug 21 2019 mvetter@suse.com
- bsc#1146555 - Drop jasper dependency from telegram-desktop:
  Remove JPEG2000 support due to removal of libjasper
* Tue Aug 20 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.2
  * Bug fixes and other minor improvements.
- Enable GTK integration for native notifications, this only works
  when libqt5-qtstyleplugins-platformtheme-gtk2 is absent
  - > introducing Conflicts with that Package
* Sat Aug 10 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.1
  * Bug fixes and other minor improvements.
* Fri Aug  9 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.0
  * Right click the Send button to send any message without sound -
    in case the recipient is sleeping.
  * Enable Slow Mode in Group Permissions to control how frequently
    members can post.
  * Set custom titles for group admins - like 'Founder', 'CFO' or
    'Spam Fighter'.
  * Toggle looped playback for animated stickers in Chat Settings.
  * Send a single :heart:, :like:, :unamused:, :flushed: or :party:
    to add a mighty animated emoji to the chat.
- Updated crl and rlottie
* Fri Jul 19 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.15
  * Bug fixes and other minor improvements.
- Allow GCC 9 after GCC#90949 was fixed
- Updated rlottie
* Sun Jul  7 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.13
  * Send ultra-lightweight high-quality animated stickers to
    express emotion with motion.
  * Receive animated stickers instantly on any connection at
    just 20-30 KB per sticker.
  * Enjoy smooth animations at 60 frames per second.
  * Create new animated sets and upload them to @stickers for
    everybody to use.
  * Try out these sample stickers: t.me/addstickers/hotcherry
  * Use strikethrough and underline formatting.
- Removed rapidjson and qtlottie, added rlottie and lz4, updated crl
- Disable LTO due to build failures
* Mon Jun 24 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.10
  * Bug fixes and other minor improvements.
- Updated libtgvoip and qtlottie
* Sun Jun 23 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.9
  * You can now add any users to your contacts, even if their phone
    numbers are not visible.
  * Transfer ownership of group chats and channels by granting full
    rights to another admin. Useful when switching jobs or if you
    just want to retire as creator.
  * Hide archived chats to the main menu.
  * See who is online straight from the chat list.
  * Use the MacBook Pro TouchBar to apply formatting to
    selected text, insert emoji, and send stickers.
- switch to ayatana-appindicator3-0.1
* Tue Jun 18 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.8
  * Hide archived chats in the main menu.
  * See who is online straight from the chat list.
  * Apply formatting to selected text parts from the
    MacBook Pro TouchBar.
* Mon Jun 10 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.7
  * Bug fixes and other minor improvements.
* Thu Jun  6 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.6
  * Bug fixes and other minor improvements.
- Updated qtlottie
* Wed Jun  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Keep using GCC8 on Tumbleweed until there is a resolution for
  https://github.com/telegramdesktop/tdesktop/issues/5996
* Wed Jun  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.5
  * Download video files while watching them using streaming.
  * Set EOL for Windows XP / Vista and OS X 10.6 to 10.9
    at September 1.
  * Crash fix.
- Remove gcc7-fix.patch because GCC7 will no longer work due to
  qtlottie requiring "class-memaccess" option
* Wed Jun  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.3
  * Bug fixes and other minor improvements.
- New 3rd party: rapidjson
* Sat Jun  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.2
  * Choose who can see your phone number with granular precision in
    Privacy & Security settings.
  * Add group chats to "Always/Never Share" exceptions for any
    privacy setting. Permissions will update as users leave
    and join the groups.
  * Connect a discussion group to your channel, subscribers will
    see a "Discuss" button.
  * Integrate bots seamlessly with web services.
    For example, see t.me/DiscussThis/1
  * Use TouchBar on MacBooks Pro to control music playback and
    switch between pinned chats.
- New 3rd party: qtlottie
* Thu May 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Updated bundled 3rd party sources to fix gcc9 build failures
  * breakpad, linux-syscall-support, gyp, crl to current master
  * libtgvoip to v2.4.4
  * mapbox-variant to v1.1.6
  * range-v3 to v0.5.0
  * xxHash to v0.7.0
- spec-cleaner: use pkconfig
* Thu May  9 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.0
- Introducing Archived Chats:
  * Archive any chat from the right-click menu.
  * Chats with enabled notifications will pop out of the archive
    when a notification arrives.
  * Muted chats will stay in the archive.
  * Pin an unlimited number of chats in your archive.
* Sat Apr 13 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.7
  * Replace media when editing messages with media content.
  * Jump quickly to the top of your chats list.
  * Get emoji suggestions for the first word you type in a message.
  * Help Telegram improve emoji suggestions in your language using
    this interface https://translations.telegram.org/en/emoji
* Thu Apr 11 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.6
  * Bug fixes and other minor improvements.
* Sat Apr  6 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.5
  * Bug fixes and other minor improvements.
* Fri Apr  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.4
  * Replace media when editing messages with media content.
  * Jump quickly to the top of your chats list.
  * Get emoji suggestions for the first word you type in a message.
  * Help Telegram improve emoji suggestions in your language using
    this interface https://translations.telegram.org/en/emoji
* Sun Mar 24 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.2
  * Delete any message on both ends in any private chat, anytime.
  * Control whether your forwarded messages link back to your account.
  * Control who may see your profile picture.
  * Enjoy the new streamlined group management screen.
* Wed Mar 20 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.1
  * Play video files and listen to received music without
    waiting for them to download.
  * Press CTRL+0 (CMD+0 on macOS) to jump to your Saved Messages.
  * Bug fixes and other minor improvements.
- Apply gcc7-fix patch on Leap 15.0 only
* Thu Feb 21 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Do not apply gcc7-fix.patch on Tumbleweed
* Wed Feb 20 2019 ramaxlo@gmail.com
- Fix build failure for openSUSE Leap 15.0.
* Tue Feb 12 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.15
  * Crash fix.
* Tue Feb 12 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.13
  * Bug fixes and other minor improvements.
* Sat Feb  9 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.12
  * Apply blur effects to backgrounds.
  * Use the backgrounds you set in Telegram Desktop in all other Telegram apps.
* Fri Feb  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.11
  * Bug fixes and other minor improvements.
* Fri Feb  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.10
  * Bug fixes and other minor improvements.
* Fri Feb  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.9
  * Bug fixes and other minor improvements.
* Tue Jan 22 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.8
  * Global permissions for groups. Restrict all members in any
    group from posting certain types of content.
  * Unified group settings. Make groups public, set admins with
    granular permissions and toggle persistent history in just a
    few clicks in any group.
  * Choose the emoji set you would like to use in Chat Settings.
  * Choose input and output devices for Telegram Calls in
    Settings > Advanced > Call Settings.
  * Support for automatically downloading files and music.
* Fri Jan 11 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.4
  * Bug fixes and other minor improvements.
  * Create polls in groups and channels - right from the chat menu.
* Thu Jan 10 2019 Ramax Lo <ramaxlo@gmail.com>
- Add TDESKTOP_DISABLE_OPENAL_EFFECTS to fix playback error:
  Audio Playback Error: 40963, Invalid Value
* Sat Dec 22 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.5.2
  * Bug fixes and other minor improvements.
  * Support for custom languages.
  * Interface scaling for large screens.
  * Video messages displayed in shared media.
* Sat Nov 17 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.4.7
  * Crash fix.
  * Bug fixes and other minor improvements
  * Listen to voice and video messages in 2X mode if you're in a hurry.
  * Find video messages in the shared voice messages section.
  * Add a comment when you share posts from channels.
  * View all photos and videos in Twitter and Instagram link previews.
  * Interface scaling for large screens, up to 300%% (up to 150%% for macOS retina screens).
  * Updated emoji.
- Add api_id and api_hash to build
* Thu Oct 11 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.4.2
  * Crash fix.
  * Reduce crashes due to the out of memory exceptions.
  * Load map previews through mtproto.
  * Bug fixes and other minor improvements.
  * Fully redesigned Settings section.
  * New theme selector in Chat Settings.
  * New local storage settings: Control how much disk space is used by the cache and for how long the cached files are stored.
  * Improved local caching for images and GIF animations.
  * New settings: Peer-to-Peer settings for calls, disable animations for low performance computers.
  * Various other improvements.
* Tue Sep 18 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid repeating name in summary.
* Mon Sep  3 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.3.15
  * Improved local files cache.
  * Move to use kservices5.
* Fri Jul 27 2018 i@xuzhao.net
- Update to 1.3.10
  * Bug fixes adn other minor improvements.
- Changes in 1.3.9
  * Mark chats in the chat list as Read or Unread.
  * Improved censorship circumvention.
* Sat Jun  2 2018 duyizhaozj321@yahoo.com
- Update to 1.3.0
  * Improved censorship circumvention.
  * Improved stability when working through proxy servers.
  * Save several proxy servers to quickly switch between them in Settings.
  * Use proxy for calls.
  * Emoji and text replacement now happens immediately after typing (instead of after sending) and can
    be rolled back using Backspace or CTRL/CMD + Z. Replacement no longer happens when pasting text.
- Changes in 1.2.25
  * Apply markdown formatting (```, `, **, __) only when sending the message.
  * Display connection quality bars in calls.
  * Telegram Desktop can update itself through MTProto.
  * Bug fixes and other minor improvements.
* Sun May 27 2018 duyizhaozj321@yahoo.com
- Update to 1.2.24
  * Add links with custom text from context menu or by Ctrl/Cmd + K keyboard shortcut.
* Sat May 26 2018 duyizhaozj321@yahoo.com
- Update to 1.2.23
  * Apply formatting from input field context menu.
  * Apply formatting by hotkeys.
  * Bug fixes and other minor improvements.
* Fri May 25 2018 i@xuzhao.net
- Update to 1.2.22
  * Use markdown in media captions (bold, italic, tag and code).
  * Use emoji replacement in media captions, group and channel titles and descriptions (:like: etc.)
  * Markdown replacement now happens immediately after typing (instead of after sending) and can be rolled back using Backspace or Ctrl/Cmd + Z.
    Replacement no longer happens when pasting text.
* Mon Apr 16 2018 ilya@ilya.cf
- Update to 1.2.17
  * Bug fixes and other minor improvements.
* Wed Mar 28 2018 ilya@ilya.cf
- Update to 1.2.15
  * Discover new stickers. Type one emoji to see suggestions from
    popular sticker sets. Suggestions from your installed sticker
    sets will come first.
  * Search for Stickers. Click on the new search icon to access
    your sticker sets or find new ones.
  * Use fast reply button in group chats.
  * Select a message you want to reply to by pressing Ctrl+Up and
    Ctrl+Down.
* Tue Mar 20 2018 ilya@ilya.cf
- Refresh spec-file via spec-cleaner and manual optimizations.
  * Add %%license and %%doc macros.
  * Remove Leap/SLE support for version < 15.
  * Increment to 4 GB of RAM for a more stable build.
  * Change Description and Summary.
* Mon Feb 26 2018 badshah400@gmail.com
- Use -a instead of -b to \%%setup to fix buing on openSUSE >=
  1500; this behaviour changed with rpm 4.14.
- Add BuildRequires: python2-base as python2 executable is needed
  for gyp scripts. It was being automatically pulled in for
  Factory, but not for Leap:15.0.
* Fri Jan 12 2018 badshah400@gmail.com
- Add Requires: libqt5-qtimageformats; required to show images of
  any kind (emoji, stickers, etc.) in the interface since the
  switch to system Qt5.
* Sun Dec 31 2017 badshah400@gmail.com
- Update to version 1.2.6:
  * Grouped Photos: Group media into an album when sharing
    multiple photos and videos. Choose the exact order of media
    you send.
  * Bug fixes and other minor improvements.
- Add crl-master.zip from https://github.com/telegramdesktop/crl
  and copy it to build dir appropriately; this is now required
  for building.
- Rebase tdesktop.patch.
* Mon Dec 18 2017 badshah400@gmail.com
- Update to version 1.2.1:
  * Bug fixes and other minor improvements.
* Fri Dec 15 2017 badshah400@gmail.com
- update patch.py to remove dee-1.0 dependency, which is not in
  use any more, and not available from factory, thus resolving
  unresolvable status.
* Wed Dec 13 2017 badshah400@gmail.com
- Update minimal versions of gcc and cmake in BuildRequires in
  keeping with upstream: gcc >= 7 (7.2) is now needed. Also update
  the gcc command exported before building on openSUSE <= 1320 to
  gcc-7.
* Mon Dec 11 2017 badshah400@gmail.com
- Update to version 1.2.0:
  * Radically improved navigation. New side panel on the right
    with quick access to shared media and group members.
  * Saved Messages. Bookmark messages by forwarding them to "Saved
    Messages". Access them from the Chats list or from the side
    menu.
  * Pinned Messages. If you are a channel admin, pin messages to
    focus your subscribers' attention on important announcements.
  * Easily recognize messages from group admins by the new 'admin'
    badge.
  * Also supported clearing history in supergroups and added a
    host of minor improvements.
- Disable parallel make for main app because the build job becomes
  terribly slow, and eventually runs out of memory otherwise.
* Fri Sep  8 2017 badshah400@gmail.com
- Update to version 1.1.23:
  * See the message author photo and name while searching specific
    chat messages.
  * Fix "Send To" menu action on Windows.
- Rebase and rename patch-1.1.19.diff to patch-1.1.23.diff.
- Add catch.hpp as source and copy to required dir; remove
  includes referring to subdirs of catch as we are using the one
  header version.
- Refresh all third-party sources to their current versions.
- Add breakpad-ucontext_t-glibc2_26.patch: Replace
  `struct ucontext` by `ucontext_t` to make breakpad compatible
  with glib-2.26; merged upstream as commit e3035bc; only apply
  for openSUSE > 1320.
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 1.1.19:
  * Search by messages of specific group members.
  * Bug fixes and other minor improvements.
- Update name of patch-1.1.18.diff to patch-1.1.19.diff (no
  rebase was needed).
* Thu Jul 27 2017 badshah400@gmail.com
- Update to version 1.1.18:
  * Minor bug fixes.
- Update name of patch-1.1.17.diff to patch-1.1.18.diff (no
  rebase was needed).
* Wed Jul 26 2017 badshah400@gmail.com
- Update to version 1.1.17:
  * Minor bug fixes.
- Update to version 1.1.16:
  * Autocompletion for emoji. Start typing :e to get suggestions.
  * Fixed a bug with forwarding messages.
- Update patch-1.1.15.diff to patch-1.1.17.diff (minor rebase).
* Mon Jul 24 2017 badshah400@gmail.com
- Update to version 1.1.15:
  * Send bold and italic text in your messages.
  * Get a share link for posts in public supergroups.
  * Quickly share posts from channels and media messages from
    bots.
  * Search large supergroup members by name.
  * Search channel members by name for admins.
  * Use search in the service actions log.
  * Ban supergroup members via the right click menu in the service
    actions log.
- Update name of patch-1.1.10.diff to patch-1.1.15.diff (no
  rebase was needed).
* Tue Jul 11 2017 badshah400@gmail.com
- Use post(un) scriptlets to update hicolor icon-theme cache, and
  the desktop database; without these the desktop menu icon does
  not get registered to the icon and picks up a default ugly icon,
  until subsequent installation of other programs or manual
  invocation of the commands corresponding to these scriptlets.
* Sat Jul  8 2017 badshah400@gmail.com
- Update to version 1.1.10:
  * Add event log filter for channel or supergroup event log.
  * Fix search by username in privacy exceptions editor.
  * Fix adding admins in channels.
* Sun Jul  2 2017 badshah400@gmail.com
- Update to version 1.1.9:
  * Supergroups can now have up to 10.000 members.
  * Appoint supergroup admins with granular rights. Choose who can
    add users, manage messages, block members, edit group info &
    username, add new admins, etc.
  * Restrict and ban supergroup members with granular precision.
    Read-only bans, GIF & sticker bans, media bans, temporary bans
    and restrictions.
  * Check the new event log to see all service actions taken by
    members and admins of a channel or supergroup in the last 48
    hours.
  * Toggle night mode in the main menu.
- Rebase patch-%%{version}.diff for updated version.
- Enforce strict version dependence for BuildRequires on
  libtelegram-qt5-devel-static = 5.6.2, since telegram does not
  build with older versions any more. Pass -Dqt_version="5.6.2"
  instead of -Dqt_version="5.6.0" when configuring for build with
  gyp.
* Wed Jun 21 2017 badshah400@gmail.com
- For openSUSE Leap, use gcc6 from the Update repository (gcc6
  from OSS is uninstallable).
- Add a _constraints file to restrict building to hardware with at
  2 GB of physical memory.
* Sun Jun  4 2017 badshah400@gmail.com
- Update to version 1.1.7.
- Add libtgvoip.zip to sources, required to build Telegram
- Rebase patch-1.0.29.diff for updated version; rename to
  patch-%%{version}.diff.
- New BuildRequires: pkgconfig(libpulse), pkgconfig(alsa); needed
  to build Telegram with audio/video support.
* Sun Apr 30 2017 badshah400@gmail.com
- Update to version 1.0.29.
- Use full URL for telegram-desktop source.
- Require gcc-c++ >= 5.0, since support for -std=gnu++14 is now
  required; on openSUSE versions <= 1320 using gcc5 or gcc6
  nonetheless leads to build failures.
- Update icon file name in keeping with upstream.
- Rebase patch-1.0.24.diff for updated version; rename it to
  patch-1.0.29.diff.
* Mon Jul 18 2016 badshah400@gmail.com
- Add %%post scriptlets to update icon theme cache and desktop
  database (BuildRequires: hicolor-icon-theme, Requires(post):
  desktop-file-utils).
- Use full URL for source.
- Run through spec-cleaner to clean up spec file according to
  openSUSE guidelines.
* Mon Jul  4 2016 i@xuzhao.net
- Upgrade to 0.9.56
- Fixed photo viewer to handle screen resolution change correctly.
- Fixed forwarding photos via drag-n-drop.
- Various design improvements and other bug fixes.
* Mon May 16 2016 i@xuzhao.net
- 0.9.48 Initial Commit.
